import React from "react";
import PropTypes from "prop-types";
import { useSelector } from "react-redux";

import { Torrent } from "./torrent";
import { Poster } from "./poster";

export const TorrentGroup = ({ torrentKey }) => {
  const torrents = useSelector((state) =>
    state.torrents.torrents.get(torrentKey)
  );

  if (torrents.length === 0) {
    return null;
  }

  const title = (torrent) => {
    switch (torrent.type) {
      case "movie":
        return torrent.video.title;
      case "episode":
        return torrent.video.show_title;
      default:
        return "Files";
    }
  };

  return (
    <div className="w-100 mb-3 card">
      <div className="row no-gutters">
        <Poster url={torrents[0].img} />
        <div className="col-sm">
          <div className="card-body">
            <h4 className="card-title">{title(torrents[0])}</h4>
            {torrents.map((torrent, i) => (
              <Torrent
                key={torrent.video ? torrent.video.imdb_id : i}
                torrent={torrent}
              />
            ))}
          </div>
        </div>
      </div>
    </div>
  );
};
TorrentGroup.propTypes = {
  torrentKey: PropTypes.string.isRequired,
};
